use true;
use MooseX::Declare;

#  PODNAME: Geo::OSM::Routing::Usecase::{{$name}}
# ABSTRACT: [Abstract for {{$name}}]


class Geo::OSM::Routing::Usecase::{{$name}} {

    use Geo::OSM::Syntax;

    use Log4Perl::ImportHandle LOG => 'runtime';

}

=begin wikidoc

= SYNOPSIS

[Short description of {{$name}}]

= OVERVIEW

For now, this is just a stub

= TODO

Here's more to tell

=end wikidoc

=cut
